@@ -19,6 +19,7 @@ import os
 import re
 import math
 from os import path
+from calculate.lib.utils.dracut import Dracut
 from calculate.lib import cl_overriding
 import sys
 import getpass
@@ -249,7 +250,27 @@ def getSupportArch():
         return ['i686']
 
 
-def getValueFromCmdLine(option, num):
+class CmdlineParams(object):
+    """
+    Параметры опции загрузки ядра calculate=
+    """
+    # названия параметров
+    Calculate = "calculate"
+    IsoscanFile = Dracut.IsoScanCmdParam
+    IOScheduler = "elevator"
+
+    # внутренние параметры calculate
+    Locale = "lang"
+    Keymap = "keymap"
+    Timezone = "timezone"
+    Resolution = "resolution"
+    Video = "video"
+    Composite = "composite"
+    Domain = "domain"
+    DomainPassword = "domain_pw"
+
+
+def getValueFromCmdLine(option, num=None):
     """Get value of parameter from boot params
     
     Parameters:
@@ -258,12 +279,20 @@ def getValueFromCmdLine(option, num):
     """
     cmdLine = "/proc/cmdline"
     calculateParam = option
-    names = ("lang", "keymap", "timezone",
-             "resolution", "video", "composite",
-             "domain", "domain_pw")
+    names = (
+        CmdlineParams.Locale,
+        CmdlineParams.Keymap,
+        CmdlineParams.Timezone,
+        CmdlineParams.Resolution,
+        CmdlineParams.Video,
+        CmdlineParams.Composite,
+        CmdlineParams.Domain,
+        CmdlineParams.DomainPassword)
     # try get timezone from kernel calculate param
     try:
-        if type(num) == str and not num.isdigit():
+        if num is None:
+            name = None
+        elif type(num) == str and not num.isdigit():
             name = num
             num = names.index(name)
         else:
@@ -272,6 +301,8 @@ def getValueFromCmdLine(option, num):
             parname, op, value = param.partition("=")
             if parname == calculateParam and op == "=":
                 # new format
+                if name is None:
+                    return value.strip()
                 if ":" in value:
                     params = dict(
                         map(lambda x: x.partition(':')[0::2],
@@ -352,7 +383,8 @@ def getVideoFromXorgConf(prefix="/"):
 
 def getVideoFromCmdLine():
     """Get video driver from cmdline"""
-    videoVal = getValueFromCmdLine("calculate", "video")
+    videoVal = getValueFromCmdLine(CmdlineParams.Calculate,
+                                   CmdlineParams.Video)
     videoVal = {'i915': 'intel'}.get(videoVal, videoVal)
     return videoVal
 
@@ -367,6 +399,7 @@ def getVideoFromModules():
                   'i915': 'intel',
                   'fglrx': 'fglrx',
                   'nvidia': 'nvidia',
+                  #'amdgpu': 'amdgpu',
                   'via': 'via',
                   'vmware': 'vmware'}
     for module, videodrv in mapModules.items():
