@@ -23,7 +23,8 @@ from calculate.lib.datavars import Variable, ReadonlyVariable
 from calculate.lib.utils.files import (readFile, process, listDirectory,
                                        isMount, pathJoin, Mounts)
 from calculate.lib.utils.device import getUdevDeviceInfo, loadEfiVars
-from calculate.lib.utils.common import getKernelUid, getValueFromCmdLine
+from calculate.lib.utils.common import getKernelUid, getValueFromCmdLine, \
+    CmdlineParams
 
 
 class VariableOsArchMachine(ReadonlyVariable):
@@ -163,7 +164,7 @@ class VariableClIsoscanPath(ReadonlyVariable):
     """
 
     def get(self):
-        return getValueFromCmdLine("iso-scan/filename", 0) or ""
+        return getValueFromCmdLine(CmdlineParams.IsoscanFile) or ""
 
 
 class VariableClIsoscanBasePath(ReadonlyVariable):
